@@ -32,11 +32,12 @@ def search_obj_from_array(array, fieldname, fieldvalue):
 
 class Timer(object):
 
-    def __init__(self):
+    def __init__(self, logger=None):
 
         self.start = time.time()
         self.end = None
         self.timings = []
+        self.logger = logger
 
     def register(self, name, info=None):
 
@@ -45,15 +46,18 @@ class Timer(object):
 
         self.timings.append((time.time(), name, info))
 
-    def done(self):
+    def done(self, send_log=True, loglvl='info', logverbose=True):
 
         self.end = time.time()
         self.timings = sorted(self.timings, key=lambda x: x[0])
 
-    def result(self, verbose=False):
+        if send_log and not self.logger is None:
+            getattr(self.logger, loglvl)('Timing done', extra=self.result(verbose=logverbose))
+
+    def result(self, verbose=True):
 
         if self.end is None:
-            self.done()
+            self.done(send_log=False)
 
         if verbose:
             timings = [{
